==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/nb.js <==
/**
 * Norwegian
 */

$.Editable.LANGS['nb'] = {
  translation: {
    "Bold": "Halvfet",
    "Italic": "Kursiv",
    "Underline": "Understreket",
    "Strikethrough": "Gjennomstreket",
    "Font Size": "St\u00f8rrelse",
    "Color": "Farge",
    "Background Color": "Bakgrunnsfarge",
    "Text Color": "Tekstfarge",
    "Format Block": "Stiler",
    "Normal": "Normal",
    "Paragraph": "Avsnitt",
    "Code": "Kode",
    "Quote": "Sitatblokk",
    "Heading 1": "Overskrift 1",
    "Heading 2": "Overskrift 2",
    "Heading 3": "Overskrift 3",
    "Heading 4": "Overskrift 4",
    "Heading 5": "Overskrift 5",
    "Heading 6": "Overskrift 6",
    "Alignment": "Justering",
    "Align Left": "Venstrejustert",
    "Align Center": "Midtstilt",
    "Align Right": "H\u00f8yrejustert",
    "Justify": "Juster alle linjer",
    "Numbered List": "Nummerliste",
    "Bulleted List": "Punktliste",
    "Indent Less": "Reduser innrykk",
    "Indent More": "\u00d8k innrykk",
    "Select All": "Marker alt",
    "Insert Link": "Sett inn lenke",
    "Insert Image": "Sett inn bilde",
    "Insert Video": "Sett inn video",
    "Undo": "Angre",
    "Redo": "Utf\u00f8r likevel",
    "Show HTML": "Vis HTML",
    "Float Left": "Venstre",
    "Float None": "Ingen",
    "Float Right": "H\u00f8yre",
    "Replace Image": "Bytt bilde",
    "Remove Image": "Fjern bilde",
    "Title": "Tittel",
    "Insert image": "Sett inn bilde",
    "Drop image": "Slippe bilde",
    "or click": "eller klikk",
    "Enter URL": "Angi URL",
    "Please wait!": "Vennligst vent!",
    "Are you sure? Image will be deleted.": "Er du sikker? Bildet vil bli slettet.",
    "UNLINK": "Fjern lenke",
    "Open in new tab": "\u00c5pne i ny fane",
    "Type something": "Skriv noe",
    "Cancel": "Avbryt",
    "OK": "OK",
    "Manage images": "Bildebehandling",
    "Delete": "Slett",
    "Font Family": "Skriftsnitt",
    "Insert Horizontal Line": "Sett inn horisontal linje"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.2.tar.gz: django-froala-editor-0.8.2/froala_editor/static/froala_editor/js/langs/nb.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Norwegian
 */

$.Editable.LANGS['nb'] = {
  translation: {
    "Bold": "Halvfet",
    "Italic": "Kursiv",
    "Underline": "Understreket",
    "Strikethrough": "Gjennomstreket",
    "Font Size": "St\u00f8rrelse",
    "Color": "Farge",
    "Background Color": "Bakgrunnsfarge",
    "Text Color": "Tekstfarge",
    "Format Block": "Stiler",
    "Normal": "Normal",
    "Paragraph": "Avsnitt",
    "Code": "Kode",
    "Quote": "Sitatblokk",
    "Heading 1": "Overskrift 1",
    "Heading 2": "Overskrift 2",
    "Heading 3": "Overskrift 3",
    "Heading 4": "Overskrift 4",
    "Heading 5": "Overskrift 5",
    "Heading 6": "Overskrift 6",
    "Alignment": "Justering",
    "Align Left": "Venstrejustert",
    "Align Center": "Midtstilt",
    "Align Right": "H\u00f8yrejustert",
    "Justify": "Juster alle linjer",
    "Numbered List": "Nummerliste",
    "Bulleted List": "Punktliste",
    "Indent Less": "Reduser innrykk",
    "Indent More": "\u00d8k innrykk",
    "Select All": "Marker alt",
    "Insert Link": "Sett inn lenke",
    "Insert Image": "Sett inn bilde",
    "Insert Video": "Sett inn video",
    "Undo": "Angre",
    "Redo": "Utf\u00f8r likevel",
    "Show HTML": "Vis HTML",
    "Float Left": "Venstre",
    "Float None": "Ingen",
    "Float Right": "H\u00f8yre",
    "Replace Image": "Bytt bilde",
    "Remove Image": "Fjern bilde",
    "Title": "Tittel",
    "Insert image": "Sett inn bilde",
    "Drop image": "Slippe bilde",
    "or click": "eller klikk",
    "Enter URL": "Angi URL",
    "Please wait!": "Vennligst vent!",
    "Are you sure? Image will be deleted.": "Er du sikker? Bildet vil bli slettet.",
    "UNLINK": "Fjern lenke",
    "Open in new tab": "\u00c5pne i ny fane",
    "Type something": "Skriv noe",
    "Cancel": "Avbryt",
    "OK": "OK",
    "Manage images": "Bildebehandling",
    "Delete": "Slett",
    "Font Family": "Skriftsnitt",
    "Insert Horizontal Line": "Sett inn horisontal linje",
    "Table": "Tabell",
    "Insert table": "Sett inn tabell",
    "Cell": "Celle",
    "Row": "Rad",
    "Column": "Kolonne",
    "Delete table": "Slett tabell",
    "Insert cell before": "Sett inn celle f\u00f8r",
    "Insert cell after": "Sett inn celle etter",
    "Delete cell": "Slett celle",
    "Merge cells": "Sl\u00e5 sammen celler",
    "Horizontal split": "Horisontalt delt",
    "Vertical split": "Vertikal split",
    "Insert row above": "Sett inn rad f\u00f8r",
    "Insert row below": "Sett in rad etter",
    "Delete row": "Slett rad",
    "Insert column before": "Sett inn kolonne f\u00f8r",
    "Insert column after": "Sett inn kolonne etter",
    "Delete column": "Slett kolonne"
  },
  direction: "ltr"
};
